import { RouteMap, ResourceConfig, NetworkClient, RestApiResource, RestApiActionHandlers, GetIdFromResource, GetResource, Resource } from '@rest-api-handler/core';
import { Reducer } from 'redux';
import { Omit } from './utils/types';
import { EnhancedStore } from './restStoreEnhancer.types';
import { GetAllResources } from './createSelectors';
export interface ConnectedRestApiResource<ResourceType extends Resource, UserClientConfig extends NetworkClient<any>, Routes extends RouteMap<ResourceType>> extends RestApiResource<ResourceType, UserClientConfig, Routes> {
    getAllResources: GetAllResources<ResourceType>;
    getIdFromResource: GetIdFromResource<ResourceType>;
    getResource: GetResource<ResourceType>;
    storeId: string;
    actions: RestApiActionHandlers;
    reducer: Reducer<Record<string | number, ResourceType>>;
    injectReduxStore: (store: EnhancedStore<any>) => void;
}
export declare function createConnectedResource<ResourceType extends Resource, UserClientConfig extends NetworkClient<any> = NetworkClient<any>, ExtraRoutes extends RouteMap<any> = Record<string, any>>(storeId: string, resourceUrl: string, networkClient: UserClientConfig, extraRoutes?: ExtraRoutes, { initialData, partialUpdate, ...resourceConfig }?: Omit<ResourceConfig<ResourceType>, 'customStore'>): ConnectedRestApiResource<ResourceType, UserClientConfig, {
    list: import("@rest-api-handler/core").RouteOptions<ResourceType, () => Record<any, string>, "list">;
    get: import("@rest-api-handler/core").RouteOptions<ResourceType, (id: ResourceType["id"]) => {
        resourceId: ResourceType["id"];
    }, "item">;
    put: import("@rest-api-handler/core").RouteOptions<ResourceType, (id: ResourceType["id"], data: ResourceType) => {
        resourceId: ResourceType["id"];
        body: ResourceType;
    }, "item">;
    patch: import("@rest-api-handler/core").RouteOptions<ResourceType, (id: ResourceType["id"], data: Partial<ResourceType>) => {
        resourceId: ResourceType["id"];
        body: Partial<ResourceType>;
    }, "item">;
    create: import("@rest-api-handler/core").RouteOptions<ResourceType, (data: import("@rest-api-handler/core/dist/utils/types").Omit<ResourceType, "id">) => {
        body: import("@rest-api-handler/core/dist/utils/types").Omit<ResourceType, "id">;
    }, "item">;
    remove: import("@rest-api-handler/core").RouteOptions<ResourceType, (id: ResourceType["id"]) => {
        resourceId: ResourceType["id"];
    }, "none">;
} & ExtraRoutes>;
