import { createActions, createReducer } from '@rest-api-handler/core';
import { REST_API_STORE_ID } from './restStoreEnhancer.types';
import { emitWarning, WarningCodes } from './warning.service';
export function createConnectedStore(storeName, initialData) {
    if (initialData === void 0) { initialData = {}; }
    // Store data
    var uId = 0;
    var reduxStore;
    var subscriptions = {};
    function subscribe(callback) {
        uId++;
        subscriptions[uId] = callback;
        return "" + uId;
    }
    function unsubscribe(id) {
        if (subscriptions[id]) {
            delete subscriptions[id];
            return true;
        }
        else {
            return false;
        }
    }
    function getState() {
        if (!reduxStore) {
            emitWarning(storeName, WarningCodes.storeNotSet);
            return {};
        }
        else {
            return reduxStore.getState()[REST_API_STORE_ID][storeName];
        }
    }
    var actions = createActions(storeName);
    var reducer = createReducer(actions, initialData);
    function dispatch(action) {
        if (!reduxStore) {
            emitWarning(storeName, WarningCodes.storeNotSet);
        }
        else {
            reduxStore.dispatch(action);
            Object.values(subscriptions).forEach(function (callback) { return callback(getState(), action); });
        }
    }
    var injectReduxStore = function (store) {
        reduxStore = store;
    };
    function getStoreName() {
        return storeName;
    }
    return {
        getState: getState,
        dispatch: dispatch,
        subscribe: subscribe,
        unsubscribe: unsubscribe,
        actions: actions,
        reducer: reducer,
        getStoreName: getStoreName,
        injectReduxStore: injectReduxStore,
    };
}
